PollDriver

Struct PollDriver 

pub struct PollDriver { /* private fields */ }
The driving pressure for events. Assuming a custom executor, this will be moved into a reactor that calls PollDriver::iter

Implementations

Source

impl PollDriver

pub fn new( timeout: impl Into<Option<Duration>>, event_buf_size: usize, ) -> IoResult<(PollDriver, PollRegistry)>

Creates a new PollDriver and corresponding PollRegistry. The registry should be passed around to register [mio::events::Source]s, while the driver will be used from within a reactor to keep pressure in the polled events.

pub fn iter(&mut self) -> IoResult<()>

Most likely, this crate will be used for creating a custom executor. Said executor should have a reactor that runs this in a loop. For error details, see mio::Poll::poll.